==> openshift-model-5.7.3-sources.jar: io/fabric8/openshift/api/model/TagImportPolicyBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class TagImportPolicyBuilder extends io.fabric8.openshift.api.model.TagImportPolicyFluentImpl<io.fabric8.openshift.api.model.TagImportPolicyBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.TagImportPolicy,io.fabric8.openshift.api.model.TagImportPolicyBuilder>{
  public TagImportPolicyBuilder() {
    this(false);
  }
  public TagImportPolicyBuilder(java.lang.Boolean validationEnabled) {
    this(new TagImportPolicy(), validationEnabled);
  }
  public TagImportPolicyBuilder(io.fabric8.openshift.api.model.TagImportPolicyFluent<?> fluent) {
    this(fluent, false);
  }
  public TagImportPolicyBuilder(io.fabric8.openshift.api.model.TagImportPolicyFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new TagImportPolicy(), validationEnabled);
  }
  public TagImportPolicyBuilder(io.fabric8.openshift.api.model.TagImportPolicyFluent<?> fluent,io.fabric8.openshift.api.model.TagImportPolicy instance) {
    this(fluent, instance, false);
  }
  public TagImportPolicyBuilder(io.fabric8.openshift.api.model.TagImportPolicyFluent<?> fluent,io.fabric8.openshift.api.model.TagImportPolicy instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withInsecure(instance.getInsecure()); 
    fluent.withScheduled(instance.getScheduled()); 
    this.validationEnabled = validationEnabled; 
  }
  public TagImportPolicyBuilder(io.fabric8.openshift.api.model.TagImportPolicy instance) {
    this(instance,false);
  }
  public TagImportPolicyBuilder(io.fabric8.openshift.api.model.TagImportPolicy instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withInsecure(instance.getInsecure()); 
    this.withScheduled(instance.getScheduled()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.TagImportPolicyFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.TagImportPolicy build() {
    TagImportPolicy buildable = new TagImportPolicy(fluent.getInsecure(),fluent.getScheduled());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TagImportPolicyBuilder that = (TagImportPolicyBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.12.0-sources.jar: io/fabric8/openshift/api/model/TagImportPolicyBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class TagImportPolicyBuilder extends io.fabric8.openshift.api.model.TagImportPolicyFluentImpl<io.fabric8.openshift.api.model.TagImportPolicyBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.TagImportPolicy,io.fabric8.openshift.api.model.TagImportPolicyBuilder>{
  public TagImportPolicyBuilder() {
    this(false);
  }
  public TagImportPolicyBuilder(java.lang.Boolean validationEnabled) {
    this(new TagImportPolicy(), validationEnabled);
  }
  public TagImportPolicyBuilder(io.fabric8.openshift.api.model.TagImportPolicyFluent<?> fluent) {
    this(fluent, false);
  }
  public TagImportPolicyBuilder(io.fabric8.openshift.api.model.TagImportPolicyFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new TagImportPolicy(), validationEnabled);
  }
  public TagImportPolicyBuilder(io.fabric8.openshift.api.model.TagImportPolicyFluent<?> fluent,io.fabric8.openshift.api.model.TagImportPolicy instance) {
    this(fluent, instance, false);
  }
  public TagImportPolicyBuilder(io.fabric8.openshift.api.model.TagImportPolicyFluent<?> fluent,io.fabric8.openshift.api.model.TagImportPolicy instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withInsecure(instance.getInsecure()); 
    fluent.withScheduled(instance.getScheduled()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public TagImportPolicyBuilder(io.fabric8.openshift.api.model.TagImportPolicy instance) {
    this(instance,false);
  }
  public TagImportPolicyBuilder(io.fabric8.openshift.api.model.TagImportPolicy instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withInsecure(instance.getInsecure()); 
    this.withScheduled(instance.getScheduled()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.TagImportPolicyFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.TagImportPolicy build() {
    TagImportPolicy buildable = new TagImportPolicy(fluent.getInsecure(),fluent.getScheduled());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TagImportPolicyBuilder that = (TagImportPolicyBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
